@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2004 Free Software Foundation
+   Copyright (C) 2000-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -105,7 +105,9 @@ NSString
 						   encoding: NSASCIIStringEncoding] 
 				  propertyList];
 	  
-	  [dict addEntriesFromDictionary: udict]; 
+	  if (udict != nil)
+	    [dict addEntriesFromDictionary: udict]; 
+	  [udict release];
 	  [self assignProjectDict:dict atPath: aPath];
 	}
     }
@@ -174,9 +176,11 @@ NSString
 // --- Dictionary
 - (BOOL)assignProjectDict:(NSDictionary *)pDict atPath:(NSString *)pPath
 {
+  NSString *tempPath = nil;
+
   NSAssert(pDict,@"No valid project dictionary!");
 
-  PCLogStatus(self, @"assignProjectDict");
+  PCLogStatus(self, @"assignProjectDict at %@", pPath);
 
   if (projectDict)
     {
@@ -188,15 +192,18 @@ NSString
   if ([[pPath lastPathComponent] isEqualToString:@"PC.project"] ||
       [[[pPath lastPathComponent] pathExtension] isEqualToString:@"pcproj"])
     {
-      [self setProjectPath:[pPath stringByDeletingLastPathComponent]];
+      tempPath = [pPath stringByDeletingLastPathComponent];
+      if ([[tempPath pathExtension] isEqualToString:@"pcproj"])
+	{
+	  tempPath = [tempPath stringByDeletingLastPathComponent];
+	}
+      [self setProjectPath:tempPath];
     }
   else
     {
       [self setProjectPath:pPath];
     }
 
-  [projectDict setObject:[NSUserDefaults userLanguages] forKey:PCUserLanguages];
-
   [self setProjectName:[projectDict objectForKey:PCProjectName]];
   [self writeMakefile];
   [self save];
@@ -224,6 +231,7 @@ NSString
     {
       if ([aDict objectForKey:key] == nil)
 	{
+	  PCLogInfo(self, @"invalid dict entry for key %@", key);
 	  return NO;
 	}
     }
@@ -398,6 +406,7 @@ NSString
     {
       [projectFileDict setObject:windows forKey:PCWindows];
       [projectFileDict writeToFile:projectFile atomically:YES];
+      [projectFileDict release];
       return YES;
     }
 
@@ -492,6 +501,7 @@ NSString
       NSRunAlertPanel(@"Save Project",
 		      @"Couldn't remove the old project backup file",
 		      @"OK",nil,nil);
+      [dict release];
       return NO;
     }
 
@@ -591,6 +601,7 @@ NSString
 
   if (isSubproject == YES)
     {
+      [projectManager closeProject:self];
       return YES;
     }
 
@@ -986,7 +997,7 @@ NSString
     }
   else if ([key isEqualToString:PCLibraries])
     {
-      return [NSArray arrayWithObjects:@"so",@"a",@"lib",nil];
+      return [NSArray arrayWithObjects:@"so",@"a",@"lib",@"dylib",nil];
     }
 
   return nil;
@@ -1517,7 +1528,7 @@ NSString
   int       i;
   PCProject *sp = nil;
   NSString  *spName = nil;
-  NSString  *spFile = nil;
+  NSString  *spPath = nil;
 
   // Subproject in project but not loaded
   if ([[projectDict objectForKey:PCSubprojects] containsObject:name])
@@ -1539,14 +1550,10 @@ NSString
       // Subproject not found in array, load it
       if (sp == nil)
 	{
-	  NSString *pname = [NSString stringWithFormat: @"%@.pcproj",name];
-	  spFile = [projectPath stringByAppendingPathComponent:name];
-	  spFile = [spFile stringByAppendingPathExtension:@"subproj"];
-	  spFile = [spFile stringByAppendingPathComponent: pname];
-	  spFile = [spFile stringByAppendingPathComponent: @"PC.project"];
-/*	  PCLogInfo(self, @"Not found! Load subproject: %@ at path: %@",
-		    name, spFile);*/
-	  sp = [projectManager openProjectAt:spFile makeActive:NO];
+	  spPath = [projectPath stringByAppendingPathComponent:name];
+	  spPath = [spPath stringByAppendingPathExtension:@"subproj"];
+
+	  sp = [projectManager openProjectAt:spPath makeActive:NO];
 	  if (sp)
 	    {
 	      [sp setIsSubproject:YES];
