@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2004 Free Software Foundation
+   Copyright (C) 2000-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -322,18 +323,8 @@
 - (NSArray *)buildArguments
 {
   NSDictionary   *projectDict = [project projectDict];
-  NSString       *instDir = [projectDict objectForKey:PCInstallDir];
   NSMutableArray *args = [NSMutableArray new];
 
-  if (![instDir isEqualToString:@"LOCAL"] &&
-      ![instDir isEqualToString:@"SYSTEM"] &&
-      ![instDir isEqualToString:@"USER"] &&
-      ![instDir isEqualToString:@"NETWORK"] &&
-      ![instDir isEqualToString:@""] &&
-      ([instDir isAbsolutePath] || [instDir characterAtIndex:0] == '$'))
-    {
-      [args addObject:[NSString stringWithFormat:@"DESTDIR=%@", instDir]];
-    }
 
   [args addObjectsFromArray:[projectDict objectForKey:PCBuilderArguments]];
 
@@ -447,14 +438,14 @@
   [buildOptions show:[[componentView window] frame]];
 }
 
-- (void)cleanupAfterMake
+- (void)cleanupAfterMake:(NSString *)statusString
 {
-  NSString *statusString;
+//  NSString *statusString;
 
   if (_isBuilding || _isCleaning)
     {
-      statusString =[NSString stringWithFormat: 
-	@"%@ - %@ terminated", [project projectName], buildStatusTarget];
+//      statusString =[NSString stringWithFormat: 
+//	@"%@ - %@ terminated", [project projectName], buildStatusTarget];
       [statusField setStringValue:statusString];
       [[project projectWindow] updateStatusLineWithText:statusString];
     }
@@ -564,30 +555,17 @@
   // Checking build conditions
   if ([self prebuildCheck] == NO)
     {
-      [self cleanupAfterMake];
+      [self cleanupAfterMake:[NSString stringWithFormat: 
+	@"%@ - %@ terminated", [project projectName], buildStatusTarget]];
       return;
     }
 
   // Prepearing to building
-  _isLogging = YES;
   stdOutPipe = [[NSPipe alloc] init];
   stdOutHandle = [stdOutPipe fileHandleForReading];
-  [stdOutHandle waitForDataInBackgroundAndNotify];
 
-  [NOTIFICATION_CENTER addObserver:self 
-                          selector:@selector(logStdOut:)
-			      name:NSFileHandleDataAvailableNotification
-			    object:stdOutHandle];
-
-  _isErrorLogging = YES;
   stdErrorPipe = [[NSPipe alloc] init];
   stdErrorHandle = [stdErrorPipe fileHandleForReading];
-  [stdErrorHandle waitForDataInBackgroundAndNotify];
-
-  [NOTIFICATION_CENTER addObserver:self 
-                          selector:@selector(logErrOut:) 
-			      name:NSFileHandleDataAvailableNotification
-			    object:stdErrorHandle];
 
   [errorsCountField setStringValue:[NSString stringWithString:@""]];
   errorsCount = 0;
@@ -620,6 +598,21 @@
   NS_DURING
     {
       [makeTask launch];
+
+      // now that we know that the task is running start logging
+      [stdOutHandle waitForDataInBackgroundAndNotify];
+      [NOTIFICATION_CENTER addObserver:self 
+			      selector:@selector(logStdOut:)
+				  name:NSFileHandleDataAvailableNotification
+				object:stdOutHandle];
+      _isLogging = YES;
+
+      [stdErrorHandle waitForDataInBackgroundAndNotify];
+      [NOTIFICATION_CENTER addObserver:self 
+			      selector:@selector(logErrOut:) 
+				  name:NSFileHandleDataAvailableNotification
+				object:stdErrorHandle];
+      _isErrorLogging = YES;
     }
   NS_HANDLER
     {
@@ -628,7 +621,7 @@
 		      @"OK", nil, nil, nil);
 		      
       //Clean up after task is terminated
-      [[NSNotificationCenter defaultCenter] 
+      [NOTIFICATION_CENTER 
 	postNotificationName:NSTaskDidTerminateNotification
 	              object:makeTask];
     }
@@ -715,7 +708,7 @@
       postProcess = NULL;
     }*/
 
-  [self cleanupAfterMake];
+  [self cleanupAfterMake:statusString];
 }
 
 // --- BuilderOptions delegate
@@ -774,14 +767,11 @@
   if ((data = [stdOutHandle availableData]) && [data length] > 0)
     {
       [self logData:data error:NO];
-    }
-
-  if (makeTask)
-    {
       [stdOutHandle waitForDataInBackgroundAndNotify];
     }
   else
     {
+      // stop logging after the task has closed the pipe
       [NOTIFICATION_CENTER removeObserver:self 
 			             name:NSFileHandleDataAvailableNotification
 			           object:stdOutHandle];
@@ -796,14 +786,11 @@
   if ((data = [stdErrorHandle availableData]) && [data length] > 0)
     {
       [self logData:data error:YES];
-    }
-
-  if (makeTask)
-    {
       [stdErrorHandle waitForDataInBackgroundAndNotify];
     }
   else
     {
+      // stop logging after the task has closed the pipe
       [NOTIFICATION_CENTER removeObserver:self 
 			             name:NSFileHandleDataAvailableNotification
 			           object:stdErrorHandle];
