@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2004 Free Software Foundation
+   Copyright (C) 2000-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -38,10 +38,12 @@
 #import <ProjectCenter/PCProjectInspector.h>
 
 #import <Protocols/Preferences.h>
+#import <Protocols/CodeEditorView.h>
 #import <ProjectCenter/PCLogController.h>
 
 #import "Modules/Preferences/Misc/PCMiscPrefs.h"
 
+
 #import <math.h>
 
 @implementation PCProjectWindow
@@ -262,6 +264,7 @@
 #endif
 
   [[NSNotificationCenter defaultCenter] removeObserver:self];
+  [projectWindow close];
 
   [super dealloc];
 }
@@ -756,6 +759,18 @@
 {
 }
 
+- (NSUndoManager *)windowWillReturnUndoManager:(NSWindow *)window
+{
+  id responder;
+
+  responder = [window firstResponder];
+  if ([responder conformsToProtocol: @protocol(CodeEditorView)])
+    {
+      return [[responder editor] windowWillReturnUndoManager: window];
+    }
+  return nil;
+}
+
 // ============================================================================
 // ==== SplitView delegate
 // ============================================================================
@@ -773,8 +788,6 @@
 //  NSLog(@"resizeVerticalSubiewsWithOldSize entered split view width: %f, height %f", splitSize.width, splitSize.height);
 
   boxRect = [v_split frame];
-  boxRect.size.width = floorf(boxRect.size.width);
-  boxRect.size.height = floorf(boxRect.size.height);
   [v_split setFrame:boxRect];
 
   if (splitSize.width == oldSize.width && splitSize.height == oldSize.height)
@@ -801,9 +814,7 @@
       // Unable to restore browser frame
       if (browserRect.size.width == 0 && browserRect.size.height == 0)
 	{
-	  browserRect = NSMakeRect(0, 0, 
-				   floorf(splitSize.width), 
-				   floorf(splitSize.height));
+	  browserRect = NSMakeRect(0, 0, splitSize.width, splitSize.height);
 	}
       [browserView setFrame:browserRect];
     }
