@@ -23,12 +23,13 @@
 #ifndef _PCINFOCONTROLLER_H
 #define _PCINFOCONTROLLER_H
 
-#include <AppKit/AppKit.h>
+#import <AppKit/AppKit.h>
 
 @interface PCInfoController : NSObject
 {
-    id infoWindow;
-    NSDictionary *infoDict;
+  id infoWindow;
+  id versionField;
+  NSDictionary *infoDict;
 }
 
 - (id)init;
