@@ -209,10 +209,15 @@
 - (void)dealloc
 {
 #ifdef DEVELOPMENT
-#endif
   NSLog(@"PCEditor: %@ dealloc", [_path lastPathComponent]);
+#endif
+
+  [_extEditorView setEditor: nil];
+  [_window setDelegate: nil];
+
 
   [[NSNotificationCenter defaultCenter] removeObserver:self];
+  [_window close];
 
   // _window is setReleasedWhenClosed:YES
   RELEASE(_path);
@@ -279,8 +284,7 @@
   [attributes setObject:textBackground forKey:NSBackgroundColorAttributeName];
 
   text  = [NSString stringWithContentsOfFile:_path];
-  [attributedString initWithString:text attributes:attributes];
-  //
+  attributedString = [attributedString initWithString:text attributes:attributes];
 
   _storage = [[NSTextStorage alloc] init];
   [_storage setAttributedString:attributedString];
@@ -502,6 +506,7 @@
       }
     }
 
+  methodRange = NSMakeRange(0, 0);
   enumerator = [parserMethods objectEnumerator];
   while ((method = [enumerator nextObject]))
     {
@@ -617,6 +622,14 @@
     postNotificationName:PCEditorWillSaveNotification
 		  object:self];
 
+  // Send the notification to Gorm...
+  if([[_path pathExtension] isEqual: @"h"])
+    {
+      [[NSDistributedNotificationCenter defaultCenter]
+	postNotificationName: @"GormParseClassNotification"
+	object: _path];
+    }
+
   saved = [[_storage string] writeToFile:_path atomically:YES];
  
   if (saved == YES)
@@ -836,7 +849,11 @@
 {
   if (editorTextViewIsPressingKey == NO)
     {
-      [self computeNewParenthesisNesting];
+      id object;
+
+      object = [notification object];
+      if (object == _intEditorView || object == _extEditorView)
+	[self computeNewParenthesisNesting: object];
     }
 }
 
@@ -845,13 +862,19 @@
   editorTextViewIsPressingKey = YES;
 //  NSLog(@"Will pressing key");
 
-  [self unhighlightCharacter];
+  if (sender == _intEditorView || sender == _extEditorView)
+    [self unhighlightCharacter: sender];
+  else
+    NSLog(@"PCEditor: unexpected sender");
 }
 
 - (void)editorTextViewDidPressKey:sender
 {
 //  NSLog(@"Did pressing key");
-  [self computeNewParenthesisNesting];
+  if (sender == _intEditorView || sender == _extEditorView)
+    [self computeNewParenthesisNesting: sender];
+  else
+    NSLog(@"PCEditor: unexpected sender");
 
   editorTextViewIsPressingKey = NO;
 }
@@ -906,6 +929,7 @@
 
   NSLog(@"SCROLL to class: \"%@\"", className);
 
+  classNameRange = NSMakeRange(0, 0);
   enumerator = [parserClasses objectEnumerator];
   while ((class = [enumerator nextObject]))
     {
@@ -933,6 +957,7 @@
 
   NSLog(@"SCROLL to method: \"%@\"", methodName);
 
+  methodNameRange = NSMakeRange(0, 0);
   enumerator = [parserMethods objectEnumerator];
   while ((method = [enumerator nextObject]))
     {
@@ -1206,10 +1231,10 @@ unsigned int FindDelimiterInString(NSString * string,
 
 @implementation PCEditor (Parenthesis)
 
-- (void)unhighlightCharacter
+- (void)unhighlightCharacter: (NSTextView *)editorView
 {
   int           i;
-  NSTextStorage *textStorage = [_intEditorView textStorage];
+  NSTextStorage *textStorage = [editorView textStorage];
 
   [textStorage beginEditing];
 
@@ -1219,7 +1244,6 @@ unsigned int FindDelimiterInString(NSString * string,
       NSRange       r = NSMakeRange(highlited_chars[i], 1);
 //      NSRange       r = NSMakeRange(highlitCharacterLocation, i);
 
-//      NSLog(@"unhighlight");
 
       isCharacterHighlit = NO;
 
@@ -1265,7 +1289,7 @@ unsigned int FindDelimiterInString(NSString * string,
   [textStorage endEditing];
 }
 
-- (void)highlightCharacterAt:(unsigned int)location
+- (void)highlightCharacterAt:(unsigned int)location inEditor: (NSTextView *)editorView
 {
   int i;
 
@@ -1274,7 +1298,7 @@ unsigned int FindDelimiterInString(NSString * string,
 //  if (isCharacterHighlit == NO)
   if (i < 2)
     {
-      NSTextStorage *textStorage = [_intEditorView textStorage];
+      NSTextStorage *textStorage = [editorView textStorage];
       NSRange       r = NSMakeRange(location, 1);
       NSRange       tmp;
 
@@ -1284,7 +1308,7 @@ unsigned int FindDelimiterInString(NSString * string,
       highlited_chars[i] = location;
 
       isCharacterHighlit = YES;
-
+      NSAssert(textStorage, @"textstorage can't be nil");
       [textStorage beginEditing];
 
       // store the previous character's attributes
@@ -1317,7 +1341,7 @@ unsigned int FindDelimiterInString(NSString * string,
     }
 }
 
-- (void)computeNewParenthesisNesting
+- (void)computeNewParenthesisNesting: (NSTextView *)editorView
 {
   NSRange  selectedRange;
   NSString *myString;
@@ -1327,19 +1351,18 @@ unsigned int FindDelimiterInString(NSString * string,
       return;
     }
 
-  selectedRange = [_intEditorView selectedRange];
+  NSAssert(editorView, @"computeNewParenthesis: editorView is nil");
+  selectedRange = [editorView selectedRange];
 
   // make sure we un-highlight a previously highlit delimiter
-  [self unhighlightCharacter];
+  [self unhighlightCharacter :editorView];
 
   // if we have a character at the selected location, check
   // to see if it is a delimiter character
-  myString = [_intEditorView string];
+  myString = [editorView string];
   if (selectedRange.length <= 1 && [myString length] > selectedRange.location)
     {
       unichar c;
-      // we must initialize these explicitly in order to make
-      // gcc shut up about flow control
       unichar oppositeDelimiter = 0;
       BOOL    searchBackwards = NO;
 
@@ -1362,8 +1385,8 @@ unsigned int FindDelimiterInString(NSString * string,
           // and in case a delimiter is found, highlight it
           if (result != NSNotFound)
             {
-              [self highlightCharacterAt:selectedRange.location];
-              [self highlightCharacterAt:result];
+              [self highlightCharacterAt:selectedRange.location inEditor:editorView];
+              [self highlightCharacterAt:result inEditor:editorView];
             }
         }
     }
