@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2004 Free Software Foundation
+   Copyright (C) 2001-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -159,16 +160,19 @@
 
   // Customise the project
   [self setProjectPath:path];
-  [self setProjectName:[path lastPathComponent]];
+  [self setProjectName: [path lastPathComponent]];
+
   if ([[projectName pathExtension] isEqualToString:@"subproj"])
     {
       projectName = [projectName stringByDeletingPathExtension];
     }
+
   [projectDict setObject:projectName forKey:PCProjectName];
   [projectDict setObject:[[NSCalendarDate date] description]
 		  forKey:PCCreationDate];
   [projectDict setObject:NSFullUserName() forKey:PCProjectCreator];
   [projectDict setObject:NSFullUserName() forKey:PCProjectMaintainer];
+  [projectDict setObject:[NSUserDefaults userLanguages] forKey:PCUserLanguages];
 
   // Copy the project files to the provided path
   _file = [projBundle pathForResource:@"main" ofType:@"m"];
@@ -479,14 +483,12 @@
       [resources addObjectsFromArray:[projectDict objectForKey:key]];
     }
   // Remove localized resource files from gathered array
-  count = [resources count];
   localizedResources = [projectDict objectForKey:PCLocalizedResources];
-  for (i = 0; i < count; i++)
+  for (i = [resources count] - 1; i >= 0; i--)
     {
       if ([localizedResources containsObject:[resources objectAtIndex:i]])
 	{
 	  [resources removeObjectAtIndex:i];
-	  count--;
 	}
     }
   [mf appendResources:resources inDir:@"Resources"];
@@ -519,48 +521,28 @@
 
 - (void)appendHead:(PCMakefileFactory *)mff
 {
-  NSString *installDir = [projectDict objectForKey:PCInstallDir];
+  NSString *installDomain = [projectDict objectForKey:PCInstallDomain];
 
   [mff appendString:@"\n#\n# Application\n#\n"];
   [mff appendString:[NSString stringWithFormat:@"VERSION = %@\n",
-    [projectDict objectForKey:PCRelease]]];
+			      [projectDict objectForKey:PCRelease]]];
   [mff appendString:
-    [NSString stringWithFormat:@"PACKAGE_NAME = %@\n", projectName]];
+	 [NSString stringWithFormat:@"PACKAGE_NAME = %@\n", projectName]];
   [mff appendString:
-    [NSString stringWithFormat:@"APP_NAME = %@\n", projectName]];
+	 [NSString stringWithFormat:@"APP_NAME = %@\n", projectName]];
     
   [mff appendString:[NSString stringWithFormat:@"%@_APPLICATION_ICON = %@\n",
-                     projectName, [projectDict objectForKey:PCAppIcon]]];
+			      projectName, [projectDict objectForKey:PCAppIcon]]];
 
-  if ([installDir isEqualToString:@""])
+  /* FIXME %@_COPY_INTO_DIR needs to be properly reinstantiated
+     as well as %@_STANDARD_INSTALL = no  */
+
+  /* set the domain if it was specified */
+  if (!(installDomain == nil) && ![installDomain isEqualToString:@""])
     {
       [mff appendString:
-	[NSString stringWithFormat:@"%@_STANDARD_INSTALL = no\n",
-        projectName]];
-    }
-  else if (![installDir isEqualToString:@"LOCAL"] &&
-	   ![installDir isEqualToString:@"SYSTEM"] &&
-	   ![installDir isEqualToString:@"USER"] &&
-	   ![installDir isEqualToString:@"NETWORK"] &&
-	   ![installDir isAbsolutePath] &&
-	   [installDir characterAtIndex:0] != '$')
-    {
-      [mff appendString:
-	[NSString stringWithFormat:@"%@_COPY_INTO_DIR = %@\n",
-        projectName, installDir]];
-    }
-  else
-    {
-      /* IMPORTANT FIXME/TODO: We should be using GNUSTEP_INSTALLATION_DOMAIN,
-       * not GNUSTEP_INSTALLATION_DIR.  Even better, we shouldn't specify
-       * this in the GNUmakefile itself at all unless explicitly requested
-       * by the user!
-       */
-      /*
-      [mff appendString:
-	[NSString stringWithFormat:@"GNUSTEP_INSTALLATION_DIR = %@\n",
-        installDir]];
-      */
+	     [NSString stringWithFormat:@"GNUSTEP_INSTALLATION_DOMAIN = %@\n",
+[installDomain uppercaseString]]];
     }
 }
 
