@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2004 Free Software Foundation
+   Copyright (C) 2004-2010 Free Software Foundation
 
    Authors: Serg Stoyan
 
@@ -103,6 +103,7 @@
                   forKey:PCCreationDate];
   [projectDict setObject:NSFullUserName() forKey:PCProjectCreator];
   [projectDict setObject:NSFullUserName() forKey:PCProjectMaintainer];
+  [projectDict setObject:[NSUserDefaults userLanguages] forKey:PCUserLanguages];
 
   // GNUmakefile.postamble
   [[PCMakefileFactory sharedFactory] createPostambleForProject:self];
@@ -151,14 +152,12 @@
       [resources addObjectsFromArray:[projectDict objectForKey:key]];
     }
   // Remove localized resource files from gathered array
-  count = [resources count];
   localizedResources = [projectDict objectForKey:PCLocalizedResources];
-  for (i = 0; i < count; i++)
+  for (i = [resources count] - 1; i >= 0; i--)
     {
       if ([localizedResources containsObject:[resources objectAtIndex:i]])
 	{
 	  [resources removeObjectAtIndex:i];
-	  count--;
 	}
     }
   [mf appendResources:resources inDir:@"Resources"];
@@ -191,7 +190,7 @@
     projectName]];
   [mff appendString:
     [NSString stringWithFormat:@"@%RESOURCE_FILES_INSTALL_DIR = %@\n",
-    [projectDict objectForKey:PCInstallDir]]];
+    [projectDict objectForKey:PCInstallDomain]]];
 }
 
 - (void)appendTail:(PCMakefileFactory *)mff
